#!/usr/bin/python
#
# DHT22 logger for Python
# 12 August, 2018
# by FUJIWARA Teruyoshi <tf@dsl.gr.jp>
#

# This program requires the following modules;
#  - pytz (available via pip)
#  - Adafruit_Python_DHT: https://github.com/adafruit/Adafruit_Python_DHT

import sys
import time
import Adafruit_DHT as DHT
import datetime as dt
import pytz

SENSOR_TYPE = DHT.DHT22
DHT_GPIO = 14

# the DHT22 specification requires an interval more than 2 seconds after reading a sensor value.
SLEEP_TIME = 60

TIME_ZONE = 'Asia/Tokyo'

time_zone = pytz.timezone(TIME_ZONE)
temperature_prev = 0
humidity_prev = 0

while True:
    humidity, temperature = DHT.read_retry(SENSOR_TYPE, DHT_GPIO)
    if temperature > 100 or humidity > 100:
        temperature = temperature_prev
        humidity = humidity_prev
    temperature_prev = temperature
    humidity_prev = humidity

    time_str = dt.datetime.strftime(time_zone.localize(dt.datetime.now()), "%Y/%m/%d %H:%M:%S %Z")
    sys.stdout.write(time_str + ", {0:0.1f}, {1:0.1f}" . format(temperature, humidity) + "\n")
    sys.stdout.flush()
    time.sleep(SLEEP_TIME)
